# This file has been generated


build_system = 'AppVeyor'
build_id = '29526455'
build_number = '409'
build_version = '1.0.409'
job_id = 'exennjemcqlja80t'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/stlib/build/job/exennjemcqlja80t'
